# fortune.sh by Chris Ausbrooks <weed@bucket.pp.ualr.edu>
# to be put in /etc/profile.d/
#
# each user can place a "~/.fortunerc" which contains the word "both",
# "dirty", or actual fortune command line data.
# In the case of no "~/.fortunerc" file the command line option "all" is
# assumed.
# Thus, in the absence of a "~/.fortunerc" file, only clean aphorisms are
# provided.
# The "both" keyword results in the "-a" option being applied, while the
# "dirty" keyword results in the "-o" option.
#
# There is also a provision for a system default option file of
# "/etc/fortunerc".
# Options in "~/.fortunerc" take precident over those in "/etc/fortunerc".
#

FORTUNE=/usr/games/fortune
OFF_DIR=/usr/share/games/fortunes/off
OPTIONS_FILE=~/.fortunerc
DEF_OPTIONS_FILE=/etc/fortunerc
OPTIONS=all

if [ -f "$DEF_OPTIONS_FILE" ]; then
	OPTIONS=`cut -d "#" -f 1 $DEF_OPTIONS_FILE`
fi

if [ -f "$OPTIONS_FILE" ]; then
	OPTIONS=`cut -d "#" -f 1 $OPTIONS_FILE`
fi

case "$OPTIONS" in
	both|-a)
		if [ -d $OFF_DIR ] ; then
			FORTUNE_OPTIONS="-a"
		else
			FORTUNE_OPTIONS="all"
		fi
	;;
	dirty|-o)
		if [ -d $OFF_DIR ] ; then
			FORTUNE_OPTIONS="-o"
		else
			FORTUNE_OPTIONS="all"
		fi
	;;
	*)
		FORTUNE_OPTIONS="$OPTIONS"
esac

fortune ()
	{
	if [ $# = 0 ] ; then
		$FORTUNE $FORTUNE_OPTIONS
	else
		$FORTUNE $*
	fi ;
	}

echo ----------------------------------------------------------------------
fortune
echo ----------------------------------------------------------------------

unset OFF_DIR
unset OPTIONS_FILE
unset DEF_OPTIONS_FILE
unset OPTIONS
